@@ -1,9 +1,8 @@
 #
-# $Id: DatabaseDesc.pm,v 1.3 2007/02/25 20:40:14 gomor Exp $
+# $Id: DatabaseDesc.pm 73 2015-01-14 06:42:49Z gomor $
 #
 package Net::Frame::Layer::OSPF::DatabaseDesc;
-use strict;
-use warnings;
+use strict; use warnings;
 
 use Net::Frame::Layer qw(:consts :subs);
 our @ISA = qw(Net::Frame::Layer);
@@ -13,6 +12,7 @@ our @AS = qw(
    options
    flags
    ddSequenceNumber
+   lls
 );
 our @AA = qw(
    lsaList
@@ -41,6 +41,9 @@ sub getLength {
    for ($self->lsaList) {
       $len += $_->getLength;
    }
+   if ($self->lls) {
+      $len += $self->lls->getLength;
+   }
    $len;
 }
 
@@ -56,6 +59,10 @@ sub pack {
       $raw .= $_->pack or return undef;
    }
 
+   if ($self->lls) {
+      $raw .= $self->lls->pack or return undef;
+   }
+
    $self->raw($raw);
 }
 
@@ -109,6 +116,10 @@ sub print {
       $buf .= "\n".$_->print;
    }
 
+   if ($self->lls) {
+      $buf .= "\n".$self->lls->print;
+   }
+
    $buf;
 }
 
@@ -125,9 +136,11 @@ Net::Frame::Layer::OSPF::DatabaseDesc - OSPF DatabaseDesc type object
    use Net::Frame::Layer::OSPF::DatabaseDesc;
 
    my $layer = Net::Frame::Layer::OSPF::DatabaseDesc->new(
-      identifier     => getRandom16bitsInt(),
-      sequenceNumber => getRandom16bitsInt(),
-      payload        => '',
+      interfaceMtu     => 1500,
+      options          => 0,
+      flags            => 0,
+      ddSequenceNumber => 1,
+      lsaList          => [],
    );
    $layer->pack;
 
@@ -150,13 +163,21 @@ See also B<Net::Frame::Layer> for other attributes and methods.
 
 =over 4
 
-=item B<identifier>
+=item B<interfaceMtu>
 
-Identification number.
+=item B<options>
 
-=item B<sequenceNumber>
+=item B<flags>
 
-Sequence number.
+=item B<ddSequenceNumber>
+
+=item B<lls>
+
+Previous attributes set and get scalar values.
+
+=item B<lsaList> ( [ B<Net::Frame::Layer::Lsa>, ... ] )
+
+This attribute takes an array ref of B<Net::Frame::Layer::Lsa> objects.
 
 =back
 
@@ -224,7 +245,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
