@@ -1,9 +1,8 @@
 #
-# $Id: LinkStateAck.pm,v 1.2 2007/02/27 23:58:56 gomor Exp $
+# $Id: LinkStateAck.pm 73 2015-01-14 06:42:49Z gomor $
 #
 package Net::Frame::Layer::OSPF::LinkStateAck;
-use strict;
-use warnings;
+use strict; use warnings;
 
 use Net::Frame::Layer qw(:consts :subs);
 our @ISA = qw(Net::Frame::Layer);
@@ -81,9 +80,7 @@ Net::Frame::Layer::OSPF::LinkStateAck - OSPF LinkStateAck type object
    use Net::Frame::Layer::OSPF::LinkStateAck;
 
    my $layer = Net::Frame::Layer::OSPF::LinkStateAck->new(
-      identifier     => getRandom16bitsInt(),
-      sequenceNumber => getRandom16bitsInt(),
-      payload        => '',
+      lsaList => [],
    );
    $layer->pack;
 
@@ -106,13 +103,9 @@ See also B<Net::Frame::Layer> for other attributes and methods.
 
 =over 4
 
-=item B<identifier>
+=item B<lsaList> ( [ B<Net::Frame::Layer::Lsa>, ... ] )
 
-Identification number.
-
-=item B<sequenceNumber>
-
-Sequence number.
+This attribute takes an array ref of B<Net::Frame::Layer::Lsa> objects.
 
 =back
 
@@ -180,7 +173,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
