@@ -1,9 +1,8 @@
 #
-# $Id: LinkStateRequest.pm,v 1.2 2007/02/28 21:02:48 gomor Exp $
+# $Id: LinkStateRequest.pm 73 2015-01-14 06:42:49Z gomor $
 #
 package Net::Frame::Layer::OSPF::LinkStateRequest;
-use strict;
-use warnings;
+use strict; use warnings;
 
 use Net::Frame::Layer qw(:consts :subs);
 our @ISA = qw(Net::Frame::Layer);
@@ -79,9 +78,9 @@ Net::Frame::Layer::OSPF::LinkStateRequest - OSPF LinkStateRequest type object
    use Net::Frame::Layer::OSPF::LinkStateRequest;
 
    my $layer = Net::Frame::Layer::OSPF::LinkStateRequest->new(
-      identifier     => getRandom16bitsInt(),
-      sequenceNumber => getRandom16bitsInt(),
-      payload        => '',
+      lsType            => 0,
+      linkStateId       => '0.0.0.0',
+      advertisingRouter => '0.0.0.0',
    );
    $layer->pack;
 
@@ -104,13 +103,11 @@ See also B<Net::Frame::Layer> for other attributes and methods.
 
 =over 4
 
-=item B<identifier>
+=item B<lsType>
 
-Identification number.
+=item B<linkStateId>
 
-=item B<sequenceNumber>
-
-Sequence number.
+=item B<advertisingRouter>
 
 =back
 
@@ -178,7 +175,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
