@@ -1,9 +1,8 @@
 #
-# $Id: Network.pm,v 1.1 2007/02/25 20:36:23 gomor Exp $
+# $Id: Network.pm 73 2015-01-14 06:42:49Z gomor $
 #
 package Net::Frame::Layer::OSPF::Lsa::Network;
-use strict;
-use warnings;
+use strict; use warnings;
 
 use Net::Frame::Layer qw(:consts :subs);
 our @ISA = qw(Net::Frame::Layer);
@@ -93,16 +92,15 @@ __END__
 
 =head1 NAME
 
-Net::Frame::Layer::OSPF::Lsa::Network - OSPF Lsa::Network type object
+Net::Frame::Layer::OSPF::Lsa::Network - OSPF Lsa Network type object
 
 =head1 SYNOPSIS
 
    use Net::Frame::Layer::OSPF::Lsa::Network;
 
    my $layer = Net::Frame::Layer::OSPF::Lsa::Network->new(
-      identifier     => getRandom16bitsInt(),
-      sequenceNumber => getRandom16bitsInt(),
-      payload        => '',
+      netmask    => '255.255.255.0',
+      routerList => [],
    );
    $layer->pack;
 
@@ -125,13 +123,13 @@ See also B<Net::Frame::Layer> for other attributes and methods.
 
 =over 4
 
-=item B<identifier>
+=item B<netmask>
 
-Identification number.
+Previous attributes set and get scalar values.
 
-=item B<sequenceNumber>
+=item B<routerList> ( [ B<IP address>, ... ] )
 
-Sequence number.
+This attribute takes an array ref of IP addresses.
 
 =back
 
@@ -199,7 +197,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
