@@ -1,9 +1,8 @@
 #
-# $Id: Opaque.pm,v 1.1 2007/01/21 20:59:24 gomor Exp $
+# $Id: Opaque.pm 73 2015-01-14 06:42:49Z gomor $
 #
 package Net::Frame::Layer::OSPF::Lsa::Opaque;
-use strict;
-use warnings;
+use strict; use warnings;
 
 use Net::Frame::Layer qw(:consts :subs);
 our @ISA = qw(Net::Frame::Layer);
@@ -62,16 +61,14 @@ __END__
 
 =head1 NAME
 
-Net::Frame::Layer::OSPF::Lsa::Opaque - OSPF Lsa type object
+Net::Frame::Layer::OSPF::Lsa::Opaque - OSPF Lsa Opaque type object
 
 =head1 SYNOPSIS
 
    use Net::Frame::Layer::OSPF::Lsa::Opaque;
 
    my $layer = Net::Frame::Layer::OSPF::Lsa::Opaque->new(
-      identifier     => getRandom16bitsInt(),
-      sequenceNumber => getRandom16bitsInt(),
-      payload        => '',
+      data => '',
    );
    $layer->pack;
 
@@ -94,13 +91,7 @@ See also B<Net::Frame::Layer> for other attributes and methods.
 
 =over 4
 
-=item B<identifier>
-
-Identification number.
-
-=item B<sequenceNumber>
-
-Sequence number.
+=item B<data>
 
 =back
 
@@ -168,7 +159,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
